module.exports = defineTest({
	description: 'simple chunking',
	options: {
		input: ['main1.js', 'main2.js', 'main3.js']
	}
});
